schemetools.Scheme
==================

.. inheritance-diagram:: abjad.tools.schemetools.Scheme.Scheme.Scheme
   :private-bases:

.. autoclass:: abjad.tools.schemetools.Scheme.Scheme.Scheme

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.Scheme.Scheme.Scheme.format

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__eq__

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__repr__

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__str__
